@@ -2,6 +2,9 @@
 Register processes, updaters, dividers, serializers upon import
 """
 
+# import matplotlib to help fix bug with import order
+import matplotlib.pyplot as plt
+
 # import registries
 from vivarium.core.registry import (
     process_registry,
@@ -18,13 +21,14 @@ from vivarium.processes.derive_counts import DeriveCounts
 from vivarium.processes.timeline import TimelineProcess
 from vivarium.processes.nonspatial_environment import NonSpatialEnvironment
 from vivarium.processes.swap_processes import SwapProcesses
-from vivarium.processes.disintegrate import Disintegrate
+from vivarium.processes.remove import Remove
 from vivarium.processes.divide_condition import DivideCondition
 
 # import updaters, dividers, serializers
 from vivarium.core.registry import (
     update_accumulate, update_set, update_merge, update_nonnegative_accumulate,
     divide_set, divide_split, divide_split_dict, divide_zero, assert_no_divide,
+    divide_binomial,
     NumpySerializer, NumpyScalarSerializer, UnitsSerializer, ProcessSerializer,
     GeneratorSerializer, FunctionSerializer
 )
@@ -39,7 +43,7 @@ process_registry.register(DeriveCounts.name, DeriveCounts)
 process_registry.register(TimelineProcess.name, TimelineProcess)
 process_registry.register(NonSpatialEnvironment.name, NonSpatialEnvironment)
 process_registry.register(SwapProcesses.name, SwapProcesses)
-process_registry.register(Disintegrate.name, Disintegrate)
+process_registry.register(Remove.name, Remove)
 
 # register updaters
 updater_registry.register('accumulate', update_accumulate)
@@ -48,6 +52,7 @@ updater_registry.register('merge', update_merge)
 updater_registry.register('nonnegative_accumulate', update_nonnegative_accumulate)
 
 # register dividers
+divider_registry.register('binomial', divide_binomial)
 divider_registry.register('set', divide_set)
 divider_registry.register('split', divide_split)
 divider_registry.register('split_dict', divide_split_dict)
