@@ -6,9 +6,7 @@ Toy Injected Glucose Phosphorylation Compartment
 This is a toy example referenced in the documentation.
 """
 
-from vivarium.core.experiment import Experiment
 from vivarium.core.process import Generator
-from vivarium.library.pretty import format_dict
 
 from vivarium.processes.glucose_phosphorylation import GlucosePhosphorylation
 from vivarium.processes.injector import Injector
