@@ -61,7 +61,8 @@ class SwapProcesses(Deriver):
             'trigger': {
                 '_default': False,
                 '_emit': True},
-            'self': {}}
+            'self': {
+                '*': {}}}
 
     def next_update(self, timestep, states):
         if states['trigger']:
@@ -103,8 +104,8 @@ class ToyLivingCompartment(Generator):
         'exchange': {'uptake_rate': 0.1},
         'death': {
             'removed_processes': [
-                ('exchange',),
-                ('death',)],
+                'exchange',
+                'death'],
             'new_compartment': ToyDeadCompartment({})
         }}
 
